@@ -30,11 +30,11 @@ DOCUMENT_CUSTOM_TERM_PREFIX = 'X'
 
 KEY_RE = re.compile(r'[_a-zA-Z][_a-zA-Z0-9]*')
 
-PREFIX_RE = re.compile(r'(?:([_a-zA-Z][_a-zA-Z0-9]*):)?("[\w.]+"|[\w.]+)')
-TERM_SPLIT_RE = re.compile(r'\W')
+PREFIX_RE = re.compile(r'(?:([_a-zA-Z][_a-zA-Z0-9]*):)?("[-\w.]+"|[-\w.]+)')
+TERM_SPLIT_RE = re.compile(r'[^-\w.]')
 
 XAPIAN_PREFER_BRASS = True
-XAPIAN_TCPSRV = 'xapian-tcpsrv-1.3'
+XAPIAN_TCPSRV = '/usr/local/bin/xapian-tcpsrv-1.3'
 if XAPIAN_PREFER_BRASS:
     os.environ['XAPIAN_PREFER_BRASS'] = '1'
 elif 'XAPIAN_PREFER_BRASS' in os.environ:
@@ -616,16 +616,16 @@ class Database(object):
             spelling = default_spelling if spelling is None else spelling
 
             term_generator = xapian.TermGenerator()
-            term_generator.set_database(database)
             term_generator.set_document(document)
+            if spelling:
+                term_generator.set_database(database)
+                term_generator.set_flags(xapian.TermGenerator.FLAG_SPELLING)
             if language:
                 term_generator.set_stemmer(xapian.Stem(language))
             if positions:
                 index_text = term_generator.index_text
             else:
                 index_text = term_generator.index_text_without_positions
-            if spelling:
-                term_generator.set_flags(xapian.TermGenerator.FLAG_SPELLING)
             index_text(normalize(text), weight, prefix.upper())
 
         return self.replace(document_id, document)
