@@ -1,3 +1,3 @@
 from __future__ import absolute_import
 
-from .server import xapiand_run  # NOQA
+from .worker import xapiand_run  # NOQA
